@@ -7,7 +7,7 @@ use warnings;
 use LWP::UserAgent;
 use Socket;
 
-our $VERSION = '1.9.2';
+our $VERSION = '1.10.0';
 
 sub new {
     my $self = { };
@@ -79,7 +79,6 @@ sub serverlist(%) {
 	$response->{servers}->{$serverport}->{serverconfig}->{maxplayerscore} = $info{maxPlayerScore};
 	$response->{servers}->{$serverport}->{serverconfig}->{maxteamscore}   = $info{maxTeamScore};
 	$response->{servers}->{$serverport}->{serverconfig}->{maxtime}        = $info{maxTime};
-	$response->{servers}->{$serverport}->{serverconfig}->{maxplayers}     = $info{maxPlayers};
 	$response->{servers}->{$serverport}->{serverconfig}->{roguemax}       = $info{rogueMax};
 	$response->{servers}->{$serverport}->{serverconfig}->{redmax}         = $info{redMax};
 	$response->{servers}->{$serverport}->{serverconfig}->{greenmax}       = $info{greenMax};
@@ -356,7 +355,7 @@ sub geterror {
 
 sub listserver {
     my $self = shift;
-    return "http://list.bzflag.bz/db/";
+    return "http://db.bzflag.org/db/";
 }
 
 1;
